# cancel_mkt_data { #shinybroker.cancel_mkt_data }

```python
cancel_mkt_data(reqId)
```

Create a message to cancel an existing market data subscription by ID

## Parameters {.doc-section .doc-section-parameters}

| Name   | Type         | Description                                                      | Default    |
|--------|--------------|------------------------------------------------------------------|------------|
| reqId  | [int](`int`) | Numeric identifier of the market data request you want to cancel | _required_ |

## Examples {.doc-section .doc-section-examples}

```
import shinybroker as sb
# create message to cancel the market data subscription whose id is 1
cancel_mkt_data_msg = sb.cancel_mkt_data(1)
print(cancel_mkt_data_msg)
```